@@ -427,8 +427,8 @@ class BinauthzManagementServiceV1Beta1RestTransport(
 
     This API implements a REST model with the following objects:
 
-    -  [Policy][google.cloud.binaryauthorization.v1beta1.Policy]
-    -  [Attestor][google.cloud.binaryauthorization.v1beta1.Attestor]
+    - [Policy][google.cloud.binaryauthorization.v1beta1.Policy]
+    - [Attestor][google.cloud.binaryauthorization.v1beta1.Attestor]
 
     This class defines the same methods as the primary client, so the
     primary client can load the underlying transport implementation
@@ -463,9 +463,10 @@ class BinauthzManagementServiceV1Beta1RestTransport(
                 are specified, the client will attempt to ascertain the
                 credentials from the environment.
 
-            credentials_file (Optional[str]): A file with credentials that can
+            credentials_file (Optional[str]): Deprecated. A file with credentials that can
                 be loaded with :func:`google.auth.load_credentials_from_file`.
-                This argument is ignored if ``channel`` is provided.
+                This argument is ignored if ``channel`` is provided. This argument will be
+                removed in the next major version of this library.
             scopes (Optional(Sequence[str])): A list of scopes. This argument is
                 ignored if ``channel`` is provided.
             client_cert_source_for_mtls (Callable[[], Tuple[bytes, bytes]]): Client
